import Pages.*;
import org.junit.jupiter.api.Test;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.chrome.ChromeDriver;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import static org.junit.Assert.*;

public class SafewayLoginTest {

    String OS;
    String browser;
    Properties safewayLoginCreds;

    @Test
    public void testSafewayLogin() throws InterruptedException {

        // Expected field values to test against
        String expectedFName = "Nisum";
        String expectedLName = "TestAcct";
        String expectedEmail = "vkrijegccvsknuvnpv@miucce.com";

        // Get browser driver for OS as well as user credentials for login
        setup();

        // Initialize test browser session
        WebDriver driver = new ChromeDriver();

        // Initialize browser control objects for Safeway.com
        HomePagePF homePage = new HomePagePF(driver);
        RightSideBarPF rightSideBar = new RightSideBarPF(driver);
        LoginModalPF loginModal = new LoginModalPF(driver);
        LoggedInHomePagePF loggedInHomePage = new LoggedInHomePagePF(driver);
        LoggedInRightSideBarPF loggedInRightSideBar = new LoggedInRightSideBarPF(driver);
        AccountSettingsPagePF accountSettingsPage = new AccountSettingsPagePF(driver);

        // Perform user login and arrive at account settings page
        homePage.visitSafewayHomepage();
        homePage.revealRightSidebar();
        rightSideBar.revealLoginModal();
        loginModal.fillUserInfo(safewayLoginCreds.getProperty("username"), safewayLoginCreds.getProperty("password"));
        loginModal.sendCredentials();
        Thread.sleep(3000);
        loggedInHomePage.revealRightSidebarLoggedIn();
        loggedInRightSideBar.revealAccountSettings();

        // Extract user info from account settings page, compare against expected

        assertEquals(expectedFName, accountSettingsPage.getFirstName());
        assertEquals(expectedLName, accountSettingsPage.getLastName());
        assertEquals(expectedEmail, accountSettingsPage.getEmail());

        // Tear down the test session. It passed
        System.out.println("ALL TEST CASES PASSED!");
        Thread.sleep(10000);
        driver.quit();
    }

    public void setup() {

        pollSystemInfo();
        pollCredentials();

        System.out.println("====================================================");
        System.out.printf("Running login test using %s on %s\n", browser, OS);
        System.out.println("username:\t" + this.safewayLoginCreds.getProperty("username"));
        System.out.println("password:\t" + this.safewayLoginCreds.getProperty("password"));
        System.out.println("====================================================");
    }

    public void pollSystemInfo() {
        /////////////////////
        // Get environment information
        /////////////////////
        this.OS = System.getProperty("os.name");
        this.browser = "Chrome";

        switch (this.OS) {
            case "Mac OS X":
                System.setProperty("webdriver.chrome.driver",
                        "/Users/kmuldoon/Dev/practice/testing/Selenium/Selenium-POM-Safeway/src/test/resources/chromedriver");
                break;
            case "Windows":
                ;
                break;
            case "Linux":
                ;
                break;
            default:
                System.out.println("Unsupported OS");
        }
    }

    public void pollCredentials() {
        /////////////////////
        // Get Login Credentials
        /////////////////////
        try (InputStream input = new FileInputStream("src/test/resources/credentials.properties")) {

            this.safewayLoginCreds = new Properties();

            // load a properties file
            this.safewayLoginCreds.load(input);


        } catch (IOException ex) {
            ex.printStackTrace();
        }
    }

}